==> haskell-crypton-x509-1.7.7-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.7
visibility:           public
id:                   crypton-x509-1.7.7-LQsOJOeijoVKAs6avnFKjN
key:                  crypton-x509-1.7.7-LQsOJOeijoVKAs6avnFKjN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  1ddd6fd8fe612a099635f9d75d8f0a3d
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.7-LQsOJOeijoVKAs6avnFKjN
depends:
    asn1-encoding-0.9.6-4QGxvmwNaLFDCNmiug7spa
    asn1-parse-0.9.5-7CQyD9IEYMX3w5AX7l5D2e
    asn1-types-0.3.4-VxacLSE1zNJE2ccrOQRFq base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.3-F6dXvDAkkF64nCV5EYjfDZ
    hourglass-0.2.12-dAUkgXLil533G2IV0frBg
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-F6Lx4W0dgQl97UPUPwjC8X transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-1.7.7-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.7
visibility:           public
id:                   crypton-x509-1.7.7-G2LNxPOT7SyGlUlsjdK8wD
key:                  crypton-x509-1.7.7-G2LNxPOT7SyGlUlsjdK8wD
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  104a8f6ec272b1ebbe8a370db1ef457e
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.7-G2LNxPOT7SyGlUlsjdK8wD
depends:
    asn1-encoding-0.9.6-9ArByk5NutrFkRwM00sH1K
    asn1-parse-0.9.5-ENTCouJIHfwGTdagrCzDYf
    asn1-types-0.3.4-3PmiJjJR5FV6kx1Sjd4xpv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.3-4ze0wyRfIfo3Yl9n4jOf0m
    hourglass-0.2.12-8Q1qeoZWxesJXv4mkKHM1d
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-6URLYrQFMhv5e9m8i14Rid transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
